.. MedUX documentation master file, created by
    sphinx-quickstart on Sat Jun 26 22:24:56 2021.
    You can adapt this file completely to your liking, but it should at least
    contain the root `toctree` directive.

Welcome to MedUX' documentation!
=================================

.. warning::
    This software is in an early development state. It's not considered to be used in production yet.
    Use it at your own risk. **You have been warned.**

.. toctree::
    :maxdepth: 2
    :caption: Contents

    development/setup
    development/deploy
    plugins

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`


License
=======

I'd like to give back what I received from many Open Source software packages. MedUX should stay as open as possible, therefore it is licensed under the `GNU Affero General Public License, version 3 <https://www.gnu.org/licenses/agpl-3.0-standalone.html>`_.
